@@ -1,7 +1,7 @@
 # --------------------------------------------------------------------------------------------------
 # Copyright (c) Lukas Vik. All rights reserved.
 #
-# This file is part of the tsfpga project.
+# This file is part of the tsfpga project, a project platform for modern FPGA development.
 # https://tsfpga.com
 # https://gitlab.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
@@ -11,11 +11,11 @@ A set of reusable functions for working with HDL projects.
 """
 
 
+# Standard libraries
 from pathlib import Path
 
-
 THIS_DIR = Path(__file__).parent
-REPO_ROOT = (THIS_DIR / "..").resolve()
+REPO_ROOT = THIS_DIR.parent.resolve()
 
 TSFPGA_PATH = REPO_ROOT / "tsfpga"
 TSFPGA_DOC = REPO_ROOT / "doc"
@@ -28,13 +28,4 @@ TSFPGA_EXAMPLE_MODULES = TSFPGA_EXAMPLES / "modules"
 # Default encoding when opening files
 DEFAULT_FILE_ENCODING = "utf-8"
 
-__version__ = "11.0.0"
-
-# Releases to PyPI are bundled with a release version of the hdl_modules
-# project (https://hdl-modules.com). These three definitions will be filled in that case.
-# This is a Path object pointing to the 'modules' folder where the hdl_modules can be found.
-HDL_MODULES_LOCATION = TSFPGA_PATH / "hdl_modules_v1.0.0_4948878705"
-# This is a string of the git tag the modules were fetched from
-HDL_MODULES_TAG = "v1.0.0"
-# This is a string of the git sha the modules were fetched from
-HDL_MODULES_SHA = "4948878705036d47875d4e5f1e5c3e2f9f91d727"
+__version__ = "12.0.0"
