@@ -1,20 +1,21 @@
 # --------------------------------------------------------------------------------------------------
 # Copyright (c) Lukas Vik. All rights reserved.
 #
-# This file is part of the tsfpga project.
+# This file is part of the tsfpga project, a project platform for modern FPGA development.
 # https://tsfpga.com
 # https://gitlab.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
+# Standard libraries
 import importlib.util
 import os
+import subprocess
 from os.path import commonpath, relpath
+from pathlib import Path
 from platform import system
 from shutil import rmtree
-import subprocess
-
-from pathlib import Path
 
+# First party libraries
 from tsfpga import DEFAULT_FILE_ENCODING
 
 
@@ -70,12 +71,30 @@ def read_last_lines_of_file(file, num_lines):
     return result
 
 
-def delete(path):
+def delete(path, wait_until_deleted=False):
+    """
+    Delete a file or directory from the filesystem.
+
+    Arguments:
+        path (pathlib.Path): The file/directory to be deleted.
+        wait_until_deleted (bool): When set to ``True``, the function will poll the filesystem
+            after initiating the deletion, and not return until the path is in fact deleted.
+            Is needed on some filesystems/mounts in a situation where we delete a path and
+            then directly want to write to it afterwards.
+
+    Returns:
+        pathlib.Path: The path that was deleted (i.e. the original ``path`` argument).
+    """
     if path.exists():
         if path.is_dir():
             rmtree(path)
         else:
             path.unlink()
+
+    if wait_until_deleted:
+        while path.exists():
+            pass
+
     return path
 
 
