@@ -1,25 +1,28 @@
 # --------------------------------------------------------------------------------------------------
 # Copyright (c) Lukas Vik. All rights reserved.
 #
-# This file is part of the tsfpga project.
+# This file is part of the tsfpga project, a project platform for modern FPGA development.
 # https://tsfpga.com
 # https://gitlab.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
+# Standard libraries
 import unittest
 from unittest.mock import MagicMock
+
+# Third party libraries
 import pytest
 
+# First party libraries
 from tsfpga.build_project_list import BuildProjectList
 from tsfpga.module import BaseModule
 from tsfpga.system_utils import create_directory
-from tsfpga.vivado.project import VivadoProject, BuildResult
+from tsfpga.vivado.project import BuildResult, VivadoProject
 
 
 # pylint: disable=too-many-instance-attributes
 @pytest.mark.usefixtures("fixture_tmp_path")
 class TestBuildProjectList(unittest.TestCase):
-
     tmp_path = None
 
     @staticmethod
@@ -61,6 +64,10 @@ class TestBuildProjectList(unittest.TestCase):
         assert len(project_list.projects) == 1
         assert self.project_one in project_list.projects
 
+        project_list = BuildProjectList(self.modules, project_filters=["one", "one", "on*"])
+        assert len(project_list.projects) == 1
+        assert self.project_one in project_list.projects
+
         project_list = BuildProjectList(self.modules, include_netlist_not_top_builds=True)
         assert len(project_list.projects) == 2
         assert self.project_three in project_list.projects
