@@ -1,19 +1,23 @@
 # --------------------------------------------------------------------------------------------------
 # Copyright (c) Lukas Vik. All rights reserved.
 #
-# This file is part of the tsfpga project.
+# This file is part of the tsfpga project, a project platform for modern FPGA development.
 # https://tsfpga.com
 # https://gitlab.com/tsfpga/tsfpga
 # --------------------------------------------------------------------------------------------------
 
-from copy import deepcopy
+# Standard libraries
 import shutil
+from copy import deepcopy
 
+# First party libraries
 from tsfpga import TSFPGA_TCL
-from tsfpga.system_utils import create_file, read_file
 from tsfpga.build_step_tcl_hook import BuildStepTclHook
+from tsfpga.system_utils import create_file, read_file
+
+# Local folder libraries
 from .build_result import BuildResult
-from .common import run_vivado_tcl, run_vivado_gui
+from .common import run_vivado_gui, run_vivado_tcl
 from .hierarchical_utilization_parser import HierarchicalUtilizationParser
 from .logic_level_distribution_parser import LogicLevelDistributionParser
 from .tcl import VivadoTcl
@@ -55,6 +59,15 @@ class VivadoProject:
                 project. These will be set in the project when it is created.
 
                 Compare to the build-time generic argument in :meth:`build`.
+
+                The generic value shall be of type
+
+                * :class:`bool` (suitable for VHDL type ``boolean`` and ``std_logic``),
+                * :class:`int` (suitable for VHDL type ``integer``, ``natural``, etc.),
+                * :class:`float` (suitable for VHDL type ``real``),
+                * :class:`.BitVectorGenericValue` (suitable for VHDL type ``std_logic_vector``,
+                  ``unsigned``, etc.), or
+                * :class:`.StringGenericValue` (suitable for VHDL type ``string``).
             constraints (list(Constraint)): Constraints that will be applied to the project.
             tcl_sources (list(pathlib.Path)): A list of TCL files. Use for e.g. block design,
                 pinning, settings, etc.
@@ -131,6 +144,19 @@ class VivadoProject:
         self.tcl_sources = tsfpga_tcl_sources + self.tcl_sources
 
     def _setup_build_step_hooks(self):
+        # Check that no ERROR messages have been sent by Vivado. After synthesis as well as
+        # after implementation.
+        self.build_step_hooks.append(
+            BuildStepTclHook(
+                TSFPGA_TCL / "check_no_error_messages.tcl", "STEPS.SYNTH_DESIGN.TCL.POST"
+            )
+        )
+        self.build_step_hooks.append(
+            BuildStepTclHook(
+                TSFPGA_TCL / "check_no_error_messages.tcl", "STEPS.WRITE_BITSTREAM.TCL.PRE"
+            )
+        )
+
         # Check the implemented timing and resource utilization via TCL build hooks.
         # This is different than for synthesis, where it is embedded in the build script.
         # This is due to Vivado limitations related to post-synthesis hooks.
@@ -250,7 +276,7 @@ class VivadoProject:
         )
         return run_vivado_tcl(self._vivado_path, create_vivado_project_tcl)
 
-    def pre_create(self, **kwargs):  # pylint: disable=no-self-use, unused-argument
+    def pre_create(self, **kwargs):  # pylint: disable=unused-argument
         """
         Override this function in a child class if you wish to do something useful with it.
         Will be called from :meth:`.create` right before the call to Vivado.
@@ -273,7 +299,14 @@ class VivadoProject:
         return True
 
     def _build_tcl(
-        self, project_path, output_path, num_threads, run_index, all_generics, synth_only
+        self,
+        project_path,
+        output_path,
+        num_threads,
+        run_index,
+        all_generics,
+        synth_only,
+        from_impl,
     ):
         """
         Make a TCL file that builds a Vivado project
@@ -292,13 +325,14 @@ class VivadoProject:
             run_index=run_index,
             generics=all_generics,
             synth_only=synth_only,
+            from_impl=from_impl,
             analyze_synthesis_timing=self.analyze_synthesis_timing,
         )
         create_file(build_vivado_project_tcl, tcl)
 
         return build_vivado_project_tcl
 
-    def pre_build(self, **kwargs):  # pylint: disable=no-self-use, unused-argument
+    def pre_build(self, **kwargs):  # pylint: disable=unused-argument
         """
         Override this function in a child class if you wish to do something useful with it.
         Will be called from :meth:`.build` right before the call to Vivado.
@@ -312,7 +346,7 @@ class VivadoProject:
         """
         return True
 
-    def post_build(self, **kwargs):  # pylint: disable=no-self-use, unused-argument
+    def post_build(self, **kwargs):  # pylint: disable=unused-argument
         """
         Override this function in a child class if you wish to do something useful with it.
         Will be called from :meth:`.build` right after the call to Vivado.
@@ -342,6 +376,7 @@ class VivadoProject:
         run_index=None,
         generics=None,
         synth_only=False,
+        from_impl=False,
         num_threads=12,
         **pre_and_post_build_parameters,
     ):
@@ -356,7 +391,10 @@ class VivadoProject:
                 generics, i.e. values that can change between each build of this project.
 
                 Compare to the create-time generics argument in :meth:`.__init__`.
+
+                The generic value types follow the same rules as for :meth:`.__init__`.
             synth_only (bool): Run synthesis and then stop.
+            from_impl (bool): Run the ``impl`` steps and onward on an existing synthesized design.
             num_threads (int): Number of parallel threads to use during run.
             pre_and_post_build_parameters: Optional further arguments. Will not be used by tsfpga,
                 but will instead be sent to
@@ -398,6 +436,7 @@ class VivadoProject:
             run_index=run_index,
             generics=all_generics,
             synth_only=synth_only,
+            from_impl=from_impl,
             num_threads=num_threads,
         )
 
@@ -434,6 +473,7 @@ class VivadoProject:
             run_index=run_index,
             all_generics=all_generics,
             synth_only=synth_only,
+            from_impl=from_impl,
         )
 
         if not run_vivado_tcl(self._vivado_path, build_vivado_project_tcl):
